@@ -19,7 +19,6 @@ import ddt
 import falcon
 from oslo_serialization import jsonutils
 from oslo_utils import uuidutils
-import six
 
 from zaqar.storage import errors as storage_errors
 from zaqar import tests as testing
@@ -216,9 +215,6 @@ class TestQueueLifecycleMongoDB(base.V2Base):
         for uri, enc in test_params:
             uri = self.url_prefix + uri
 
-            if six.PY2:
-                uri = uri.encode(enc)
-
             self.simulate_put(uri, headers=self.headers)
             self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
